==> QupZilla-1.3.5.tar.gz: QupZilla-1.3.5/src/plugins/MouseGestures/translations/es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>MouseGesturesSettingsDialog</name>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="14"/>
        <source>Mouse Gestures</source>
        <translation>Gestos del ratón</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="42"/>
        <source>&lt;h1&gt;Mouse Gestures&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;Gestos del ratón&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="64"/>
        <source>Press and hold the middle mouse button and move your mouse in the indicated directions.</source>
        <translation>Pulse y mantenga el botón central del ratón y mueva el ratón en las direcciones indicadas.</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="111"/>
        <source>&lt;b&gt;Stop&lt;/b&gt;&lt;br/&gt;Stop loading page</source>
        <translation>&lt;b&gt;Detener&lt;/b&gt;&lt;br/&gt;Detener la carga de la página</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="125"/>
        <source>&lt;b&gt;New tab&lt;/b&gt;&lt;br/&gt;Open new tab</source>
        <translation>&lt;b&gt;Nueva pestaña&lt;/b&gt;&lt;br/&gt;Abrir nueva pestaña</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="139"/>
        <source>&lt;b&gt;Back&lt;/b&gt;&lt;br/&gt;Go back in history</source>
        <translation>&lt;b&gt;Anterior&lt;/b&gt;&lt;br/&gt;Ir a la página anterior</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="187"/>
        <source>&lt;b&gt;Forward&lt;/b&gt;&lt;br/&gt;Go forward in history</source>
        <translation>&lt;b&gt;Siguiente&lt;/b&gt;&lt;br/&gt;Ir a la página siguiente</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="194"/>
        <source>&lt;b&gt;Previous tab&lt;/b&gt;&lt;br/&gt;Switch to previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="222"/>
        <source>&lt;b&gt;Next tab&lt;/b&gt;&lt;br/&gt;Switch to next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="159"/>
        <source>&lt;b&gt;Reload&lt;/b&gt;&lt;br/&gt;Reload page</source>
        <translation>&lt;b&gt;Actualizar&lt;/b&gt;&lt;br/&gt;Actualizar página</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="173"/>
        <source>&lt;b&gt;Close tab&lt;/b&gt;&lt;br/&gt;Close current tab</source>
        <translation>&lt;b&gt;Cerrar pestaña&lt;/b&gt;&lt;br/&gt;Cerrar la pestaña actual</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="208"/>
        <source>&lt;b&gt;Home&lt;/b&gt;&lt;br/&gt;Go to homepage</source>
        <translation>&lt;b&gt;Inicio&lt;/b&gt;&lt;br/&gt;Ir a la página de inicio</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="253"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
</TS>

==> QupZilla-1.4.3.tar.gz: QupZilla-1.4.3/src/plugins/MouseGestures/translations/es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>MouseGesturesSettingsDialog</name>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="14"/>
        <source>Mouse Gestures</source>
        <translation>Gestos del ratón</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="42"/>
        <source>&lt;h1&gt;Mouse Gestures&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;Gestos del ratón&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="64"/>
        <source>Press and hold the middle mouse button and move your mouse in the indicated directions.</source>
        <translation>Pulse y mantenga el botón central del ratón y mueva el ratón en las direcciones indicadas.</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="111"/>
        <source>&lt;b&gt;Stop&lt;/b&gt;&lt;br/&gt;Stop loading page</source>
        <translation>&lt;b&gt;Detener&lt;/b&gt;&lt;br/&gt;Detener la carga de la página</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="125"/>
        <source>&lt;b&gt;New tab&lt;/b&gt;&lt;br/&gt;Open new tab</source>
        <translation>&lt;b&gt;Nueva pestaña&lt;/b&gt;&lt;br/&gt;Abrir nueva pestaña</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="139"/>
        <source>&lt;b&gt;Back&lt;/b&gt;&lt;br/&gt;Go back in history</source>
        <translation>&lt;b&gt;Anterior&lt;/b&gt;&lt;br/&gt;Ir a la página anterior</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="159"/>
        <source>&lt;b&gt;Reload&lt;/b&gt;&lt;br/&gt;Reload page</source>
        <translation>&lt;b&gt;Actualizar&lt;/b&gt;&lt;br/&gt;Actualizar página</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="173"/>
        <source>&lt;b&gt;Close tab&lt;/b&gt;&lt;br/&gt;Close current tab</source>
        <translation>&lt;b&gt;Cerrar pestaña&lt;/b&gt;&lt;br/&gt;Cerrar la pestaña actual</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="187"/>
        <source>&lt;b&gt;Forward&lt;/b&gt;&lt;br/&gt;Go forward in history</source>
        <translation>&lt;b&gt;Siguiente&lt;/b&gt;&lt;br/&gt;Ir a la página siguiente</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="194"/>
        <source>&lt;b&gt;Previous tab&lt;/b&gt;&lt;br/&gt;Switch to previous tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="208"/>
        <source>&lt;b&gt;Home&lt;/b&gt;&lt;br/&gt;Go to homepage</source>
        <translation>&lt;b&gt;Inicio&lt;/b&gt;&lt;br/&gt;Ir a la página de inicio</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="222"/>
        <source>&lt;b&gt;Next tab&lt;/b&gt;&lt;br/&gt;Switch to next tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="253"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
</TS>
